summaryrefslogtreecommitdiffstats
path: root/src/gui/application/RosegardenGUIView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/application/RosegardenGUIView.h')
-rw-r--r--src/gui/application/RosegardenGUIView.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/gui/application/RosegardenGUIView.h b/src/gui/application/RosegardenGUIView.h
index b3727f3..1c2e3b1 100644
--- a/src/gui/application/RosegardenGUIView.h
+++ b/src/gui/application/RosegardenGUIView.h
@@ -32,12 +32,12 @@
#include "base/Track.h"
#include "sound/AudioFile.h"
#include "gui/editors/segment/TrackEditor.h"
-#include <qstring.h>
-#include <qvbox.h>
+#include <tqstring.h>
+#include <tqvbox.h>
-class QWidget;
-class QObject;
+class TQWidget;
+class TQObject;
class LevelInfo;
class KCommand;
@@ -64,7 +64,7 @@ class LevelInfo;
/**
* The RosegardenGUIView class provides the view widget for the
* RosegardenGUIApp instance. The View instance inherits QWidget as a
* base class and represents the view object of a KTMainWindow. As
* RosegardenGUIView is part of the docuement-view model, it needs a
* reference to the document object connected with it by the
@@ -86,7 +86,7 @@ public:
SegmentParameterBox*,
InstrumentParameterBox*,
TrackParameterBox*,
- QWidget *parent = 0,
+ TQWidget *parent = 0,
const char *name=0);
/**
@@ -122,7 +122,7 @@ public:
/**
* Select a tool at the SegmentCanvas
*/
- void selectTool(QString toolName);
+ void selectTool(TQString toolName);
/**
* Show output levels
@@ -143,7 +143,7 @@ public:
SegmentSelection getSelection();
void updateSelectionContents();
- static bool isMainWindowLastActive(const QWidget *w) {
+ static bool isMainWindowLastActive(const TQWidget *w) {
return w == m_lastActiveMainWindow;
}
@@ -162,7 +162,7 @@ public slots:
void slotSegmentAutoSplit(Segment*);
void slotEditRepeat(Segment*, timeT);
/* hjj: WHAT DO DO WITH THIS ?
- void slotEditMetadata(QString);
+ void slotEditMetadata(TQString);
*/
/**
@@ -215,8 +215,8 @@ public slots:
const RealTime &startTime,
const RealTime &endTime);
- void slotDroppedAudio(QString audioDesc);
- void slotDroppedNewAudio(QString audioDesc);
+ void slotDroppedAudio(TQString audioDesc);
+ void slotDroppedNewAudio(TQString audioDesc);
/*
* Commands
@@ -227,12 +227,12 @@ public slots:
/*
* Change the Instrument Label
*/
- void slotChangeInstrumentLabel(InstrumentId id, QString label);
+ void slotChangeInstrumentLabel(InstrumentId id, TQString label);
/*
* Change the Track Label
*/
- void slotChangeTrackLabel(TrackId id, QString label);
+ void slotChangeTrackLabel(TrackId id, TQString label);
/*
* Set the mute button on the track buttons and on the instrument
@@ -269,7 +269,7 @@ public slots:
* another application entirely but still receiving MIDI etc in
* Rosegarden.)
*/
- void slotActiveMainWindowChanged(const QWidget *);
+ void slotActiveMainWindowChanged(const TQWidget *);
void slotActiveMainWindowChanged(); // uses sender()
/**
@@ -280,9 +280,9 @@ public slots:
void slotControllerDeviceEventReceived(MappedEvent *, const void *);
signals:
- void activateTool(QString toolName);
+ void activateTool(TQString toolName);
- void stateChange(QString, bool);
+ void stateChange(TQString, bool);
// Inform that we've got a SegmentSelection
//
@@ -301,10 +301,10 @@ signals:
* This signal is used to dispatch a notification for a request to
* set the step-by-step-editing target window to all candidate targets,
* so that they can either know that their request has been granted
* (if they match the QObject passed) or else deactivate any step-by-
* step editing currently active in their own window (otherwise).
*/
- void stepByStepTargetRequested(QObject *);
+ void stepByStepTargetRequested(TQObject *);
/*
* Add an audio file at the sequencer - when we drop a new file
@@ -338,7 +338,7 @@ protected:
InstrumentParameterBox *m_instrumentParameterBox;
TrackParameterBox *m_trackParameterBox;
- static const QWidget *m_lastActiveMainWindow;
+ static const TQWidget *m_lastActiveMainWindow;
};
@@ -64,7 +64,7 @@ class LevelInfo;
/**
* The RosegardenGUIView class provides the view widget for the
- * RosegardenGUIApp instance. The View instance inherits QWidget as a
+ * RosegardenGUIApp instance. The View instance inherits TQWidget as a
* base class and represents the view object of a KTMainWindow. As
* RosegardenGUIView is part of the docuement-view model, it needs a
@@ -301,10 +301,10 @@ signals:
* set the step-by-step-editing target window to all candidate targets,
* so that they can either know that their request has been granted
- * (if they match the QObject passed) or else deactivate any step-by-
+ * (if they match the TQObject passed) or else deactivate any step-by-
* step editing currently active in their own window (otherwise).
*/